Coverage for tictactoe/manage: 100%

# Coverage for tictactoe/manage : 100%

## 8 statements 8 run 0 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 | #!/usr/bin/env python import os import sys def main(): os.environ.setdefault("DJANGO_SETTINGS_MODULE", "tictactoe.settings") from django.core.management import execute_from_command_line execute_from_command_line(sys.argv) if __name__ == "__main__": main()